==> codebuild-1.60.0-sources.jar: software/amazon/awscdk/services/codebuild/ArtifactsConfig.java <==
package software.amazon.awscdk.services.codebuild;

/**
 * The type returned from {@link IArtifacts#bind}.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:27.904Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.codebuild.$Module.class, fqn = "@aws-cdk/aws-codebuild.ArtifactsConfig")
@software.amazon.jsii.Jsii.Proxy(ArtifactsConfig.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ArtifactsConfig extends software.amazon.jsii.JsiiSerializable {

    /**
     * The low-level CloudFormation artifacts property.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.codebuild.CfnProject.ArtifactsProperty getArtifactsProperty();

    /**
     * @return a {@link Builder} of {@link ArtifactsConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ArtifactsConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<ArtifactsConfig> {
        private software.amazon.awscdk.services.codebuild.CfnProject.ArtifactsProperty artifactsProperty;

        /**
         * Sets the value of {@link ArtifactsConfig#getArtifactsProperty}
         * @param artifactsProperty The low-level CloudFormation artifacts property. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder artifactsProperty(software.amazon.awscdk.services.codebuild.CfnProject.ArtifactsProperty artifactsProperty) {
            this.artifactsProperty = artifactsProperty;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ArtifactsConfig}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public ArtifactsConfig build() {
            return new Jsii$Proxy(artifactsProperty);
        }
    }

    /**
     * An implementation for {@link ArtifactsConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ArtifactsConfig {
        private final software.amazon.awscdk.services.codebuild.CfnProject.ArtifactsProperty artifactsProperty;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.artifactsProperty = this.jsiiGet("artifactsProperty", software.amazon.awscdk.services.codebuild.CfnProject.ArtifactsProperty.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final software.amazon.awscdk.services.codebuild.CfnProject.ArtifactsProperty artifactsProperty) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.artifactsProperty = java.util.Objects.requireNonNull(artifactsProperty, "artifactsProperty is required");
        }

        @Override
        public software.amazon.awscdk.services.codebuild.CfnProject.ArtifactsProperty getArtifactsProperty() {
            return this.artifactsProperty;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("artifactsProperty", om.valueToTree(this.getArtifactsProperty()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-codebuild.ArtifactsConfig"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ArtifactsConfig.Jsii$Proxy that = (ArtifactsConfig.Jsii$Proxy) o;

            return this.artifactsProperty.equals(that.artifactsProperty);
        }

        @Override
        public int hashCode() {
            int result = this.artifactsProperty.hashCode();
            return result;
        }
    }
}

==> codebuild-1.93.0-sources.jar: software/amazon/awscdk/services/codebuild/ArtifactsConfig.java <==
package software.amazon.awscdk.services.codebuild;

/**
 * The type returned from {@link IArtifacts#bind}.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:44.745Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.codebuild.$Module.class, fqn = "@aws-cdk/aws-codebuild.ArtifactsConfig")
@software.amazon.jsii.Jsii.Proxy(ArtifactsConfig.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ArtifactsConfig extends software.amazon.jsii.JsiiSerializable {

    /**
     * The low-level CloudFormation artifacts property.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.codebuild.CfnProject.ArtifactsProperty getArtifactsProperty();

    /**
     * @return a {@link Builder} of {@link ArtifactsConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ArtifactsConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<ArtifactsConfig> {
        private software.amazon.awscdk.services.codebuild.CfnProject.ArtifactsProperty artifactsProperty;

        /**
         * Sets the value of {@link ArtifactsConfig#getArtifactsProperty}
         * @param artifactsProperty The low-level CloudFormation artifacts property. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder artifactsProperty(software.amazon.awscdk.services.codebuild.CfnProject.ArtifactsProperty artifactsProperty) {
            this.artifactsProperty = artifactsProperty;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ArtifactsConfig}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public ArtifactsConfig build() {
            return new Jsii$Proxy(artifactsProperty);
        }
    }

    /**
     * An implementation for {@link ArtifactsConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ArtifactsConfig {
        private final software.amazon.awscdk.services.codebuild.CfnProject.ArtifactsProperty artifactsProperty;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.artifactsProperty = software.amazon.jsii.Kernel.get(this, "artifactsProperty", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codebuild.CfnProject.ArtifactsProperty.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final software.amazon.awscdk.services.codebuild.CfnProject.ArtifactsProperty artifactsProperty) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.artifactsProperty = java.util.Objects.requireNonNull(artifactsProperty, "artifactsProperty is required");
        }

        @Override
        public final software.amazon.awscdk.services.codebuild.CfnProject.ArtifactsProperty getArtifactsProperty() {
            return this.artifactsProperty;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("artifactsProperty", om.valueToTree(this.getArtifactsProperty()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-codebuild.ArtifactsConfig"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ArtifactsConfig.Jsii$Proxy that = (ArtifactsConfig.Jsii$Proxy) o;

            return this.artifactsProperty.equals(that.artifactsProperty);
        }

        @Override
        public final int hashCode() {
            int result = this.artifactsProperty.hashCode();
            return result;
        }
    }
}
